Header menu logo Nu

AssimpContext Module

Functions and values

Function or value Description

AssimpContext.TryGetScene filePath

Full Usage: AssimpContext.TryGetScene filePath

Parameters:
    filePath : string

Returns: Either<string, Scene>

Attempt to load an assimp scene from the given file path, using an existing one if already loaded. Thread-safe.

filePath : string
Returns: Either<string, Scene>

AssimpContext.Wipe ()

Full Usage: AssimpContext.Wipe ()

Parameters:
    () : unit

Clear the assimp scene cache. Thread-safe.

() : unit

Type something to start searching.