BodyId Type
Identifies a body that can be found in a physics engine. Note that this is an ephermeral type and not intended to be persisted.
Record fields
| Record Field | Description |
Full Usage:
BodyIndex
Field type: int
|
|
|
|
Static members
| Static member | Description |
|
|
|
|
|
Nu