BoxRoundedShape Type
The shape of a physics body rounded box, where the radius is intrinsic to the box size.
Record fields
| Record Field | Description |
|
|
Full Usage:
Radius
Field type: single
|
|
|
|
|
|
Nu