ContourShape Type
The shape of a massless physics body in terms of at least 4 points, each consecutive pair of points forming a link. Collision occurs one-sided at the right hand side of each link (a counter-clockwise winding order orients the normal outwards and a clockwise winding order orients the normal inwards). When closed, an additional link is implied between the last link and the first. Otherwise, the first link and the last link provide no collision and are used to overlap another contour shape at its second or second-to-last link.
Record fields
| Record Field | Description |
Full Usage:
Closed
Field type: bool
|
|
|
|
|
|
|
|
Nu