Header menu logo Nu

CursorType Type

The type of a system cursor.

Union cases

Union case Description

CrosshairCursor

Full Usage: CrosshairCursor

Crosshair.

DefaultCursor

Full Usage: DefaultCursor

Default cursor. Usually an arrow.

MoveCursor

Full Usage: MoveCursor

Four pointed arrow pointing north, south, east, and west.

NotAllowedCursor

Full Usage: NotAllowedCursor

Not permitted. Usually a slashed circle or crossbones.

PointerCursor

Full Usage: PointerCursor

Pointer that indicates a link. Usually a pointing hand.

ProgressCursor

Full Usage: ProgressCursor

Program is busy but still interactive. Usually it's WaitCursor with an arrow.

ResizeEastCursor

Full Usage: ResizeEastCursor

Window resize right. This may be a single arrow or a double arrow like ResizeEastWestCursor.

ResizeEastWestCursor

Full Usage: ResizeEastWestCursor

Double arrow pointing west and east.

ResizeNeswCursor

Full Usage: ResizeNeswCursor

Double arrow pointing northeast and southwest.

ResizeNorthCursor

Full Usage: ResizeNorthCursor

Window resize top. This may be a single arrow or a double arrow like ResizeNorthSouthCursor.

ResizeNorthEastCursor

Full Usage: ResizeNorthEastCursor

Window resize top-right. This may be a single arrow or a double arrow like ResizeNeswCursor.

ResizeNorthSouthCursor

Full Usage: ResizeNorthSouthCursor

Double arrow pointing north and south.

ResizeNorthWestCursor

Full Usage: ResizeNorthWestCursor

Window resize top-left. This may be a single arrow or a double arrow like ResizeNwseCursor.

ResizeNwseCursor

Full Usage: ResizeNwseCursor

Double arrow pointing northwest and southeast.

ResizeSouthCursor

Full Usage: ResizeSouthCursor

Window resize bottom. This may be a single arrow or a double arrow like ResizeNorthSouthCursor.

ResizeSouthEastCursor

Full Usage: ResizeSouthEastCursor

Window resize bottom-right. This may be a single arrow or a double arrow like ResizeNwseCursor.

ResizeSouthWestCursor

Full Usage: ResizeSouthWestCursor

Window resize bottom-left. This may be a single arrow or a double arrow like ResizeNeswCursor.

ResizeWestCursor

Full Usage: ResizeWestCursor

Window resize left. This may be a single arrow or a double arrow like ResizeEastWestCursor.

TextCursor

Full Usage: TextCursor

Text selection. Usually an I-beam.

UserDefinedCursor AssetTag

Full Usage: UserDefinedCursor AssetTag

Parameters:

User-defined cursor loaded from a cursor asset.

AssetTag : Cursor AssetTag

WaitCursor

Full Usage: WaitCursor

Wait. Usually an hourglass or watch or spinning ball.

Instance members

Instance member Description

this.IsCrosshairCursor

Full Usage: this.IsCrosshairCursor

Returns: bool
Returns: bool

this.IsDefaultCursor

Full Usage: this.IsDefaultCursor

Returns: bool
Returns: bool

this.IsMoveCursor

Full Usage: this.IsMoveCursor

Returns: bool
Returns: bool

this.IsNotAllowedCursor

Full Usage: this.IsNotAllowedCursor

Returns: bool
Returns: bool

this.IsPointerCursor

Full Usage: this.IsPointerCursor

Returns: bool
Returns: bool

this.IsProgressCursor

Full Usage: this.IsProgressCursor

Returns: bool
Returns: bool

this.IsResizeEastCursor

Full Usage: this.IsResizeEastCursor

Returns: bool
Returns: bool

this.IsResizeEastWestCursor

Full Usage: this.IsResizeEastWestCursor

Returns: bool
Returns: bool

this.IsResizeNeswCursor

Full Usage: this.IsResizeNeswCursor

Returns: bool
Returns: bool

this.IsResizeNorthCursor

Full Usage: this.IsResizeNorthCursor

Returns: bool
Returns: bool

this.IsResizeNorthEastCursor

Full Usage: this.IsResizeNorthEastCursor

Returns: bool
Returns: bool

this.IsResizeNorthSouthCursor

Full Usage: this.IsResizeNorthSouthCursor

Returns: bool
Returns: bool

this.IsResizeNorthWestCursor

Full Usage: this.IsResizeNorthWestCursor

Returns: bool
Returns: bool

this.IsResizeNwseCursor

Full Usage: this.IsResizeNwseCursor

Returns: bool
Returns: bool

this.IsResizeSouthCursor

Full Usage: this.IsResizeSouthCursor

Returns: bool
Returns: bool

this.IsResizeSouthEastCursor

Full Usage: this.IsResizeSouthEastCursor

Returns: bool
Returns: bool

this.IsResizeSouthWestCursor

Full Usage: this.IsResizeSouthWestCursor

Returns: bool
Returns: bool

this.IsResizeWestCursor

Full Usage: this.IsResizeWestCursor

Returns: bool
Returns: bool

this.IsTextCursor

Full Usage: this.IsTextCursor

Returns: bool
Returns: bool

this.IsUserDefinedCursor

Full Usage: this.IsUserDefinedCursor

Returns: bool
Returns: bool

this.IsWaitCursor

Full Usage: this.IsWaitCursor

Returns: bool
Returns: bool

Type something to start searching.