FluidParticleConfig Type
Configuration for a fluid particle in a particle-based fluid simulation. See sfml-box2d-fluid: Game.cpp, Game::InitFluid TODO: rename this and member vals from XxxConfig to XxxProperties? NOTE: sfml-box2d-fluid is under rewrite, it is not recommended to tune for these parameters as a future update would change things up.
Record fields
| Record Field | Description |
Full Usage:
CollisionCategories
Field type: uint64
|
|
Full Usage:
CollisionMask
Field type: uint64
|
|
Full Usage:
Density
Field type: single
|
|
Full Usage:
DensityMax
Field type: single
|
|
Full Usage:
DensityMin
Field type: single
|
|
Full Usage:
ForceAdhesion
Field type: single
|
|
Full Usage:
ForceDamping
Field type: single
|
|
Full Usage:
ForceMax
Field type: single
|
|
Full Usage:
ForceMultiplier
Field type: single
|
|
Full Usage:
ForceSurface
Field type: single
|
|
Full Usage:
Friction
Field type: single
|
|
Full Usage:
GetForceMax
Field type: single
|
|
|
|
Full Usage:
Impact
Field type: single
|
|
Full Usage:
LinearDamping
Field type: single
|
|
Full Usage:
Radius
Field type: single
|
|
Full Usage:
Restitution
Field type: single
|
|
Full Usage:
ShearViscosity
Field type: single
|
|
Full Usage:
SurfaceWithOther
Field type: bool
|
|
Full Usage:
Viscosity
Field type: single
|
|
Full Usage:
ViscosityLeave
Field type: single
|
|
Static members
| Static member | Description |
|
|
|
|
|
|
|
|
|
|
Nu