Header menu logo Nu

PathF Type

Performs operations on System.String instances that contain file or directory path information. These operations are performed in a normalized manner where '/' is always used as the directory separator.

Static members

Static member Description

PathF.ChangeExtension(path, extension)

Full Usage: PathF.ChangeExtension(path, extension)

Parameters:
    path : string
    extension : string

Returns: string

Changes the extension of a path string.

path : string
extension : string
Returns: string

PathF.Combine(paths)

Full Usage: PathF.Combine(paths)

Parameters:
    paths : string[]

Returns: string

Combines two strings into a path.

paths : string[]
Returns: string

PathF.Denormalize(path)

Full Usage: PathF.Denormalize(path)

Parameters:
    path : string

Returns: string

Denormalize a path to use '\\' separators.

path : string
Returns: string

PathF.GetDirectoryName(path)

Full Usage: PathF.GetDirectoryName(path)

Parameters:
    path : string

Returns: string

Returns the directory information for the specified path.

path : string
Returns: string

PathF.GetExtensionLower(path)

Full Usage: PathF.GetExtensionLower(path)

Parameters:
    path : string

Returns: string

Returns the lower-cased extension (including the period ".") of the specified path string.

path : string
Returns: string

PathF.GetExtensionMixed(path)

Full Usage: PathF.GetExtensionMixed(path)

Parameters:
    path : string

Returns: string

Returns the mixed-case (unaltered) extension (including the period ".") of the specified path string.

path : string
Returns: string

PathF.GetExtensionUpper(path)

Full Usage: PathF.GetExtensionUpper(path)

Parameters:
    path : string

Returns: string

Returns the upper-cased extension (including the period ".") of the specified path string.

path : string
Returns: string

PathF.GetFileName(path)

Full Usage: PathF.GetFileName(path)

Parameters:
    path : string

Returns: string

Returns the file name and extension of the specified path string.

path : string
Returns: string

PathF.GetFileNameWithoutExtension(path)

Full Usage: PathF.GetFileNameWithoutExtension(path)

Parameters:
    path : string

Returns: string

Returns the file name of the specified path string without the extension.

path : string
Returns: string

PathF.GetFullPath(path)

Full Usage: PathF.GetFullPath(path)

Parameters:
    path : string

Returns: string

Returns the absolute path for the specified path string.

path : string
Returns: string

PathF.GetInvalidFileNameChars()

Full Usage: PathF.GetInvalidFileNameChars()

Returns: char[]

Gets an array containing the characters that are not allowed in file names.

Returns: char[]

PathF.GetInvalidPathChars()

Full Usage: PathF.GetInvalidPathChars()

Returns: char[]

Gets an array containing the characters that are not allowed in path names.

Returns: char[]

PathF.GetRelativePath(relativeTo, path)

Full Usage: PathF.GetRelativePath(relativeTo, path)

Parameters:
    relativeTo : string
    path : string

Returns: string

Returns a relative path from one path to another.

relativeTo : string
path : string
Returns: string

PathF.HasExtension(path)

Full Usage: PathF.HasExtension(path)

Parameters:
    path : string

Returns: bool

Determines whether a path includes a file name extension.

path : string
Returns: bool

PathF.Normalize(path)

Full Usage: PathF.Normalize(path)

Parameters:
    path : string

Returns: string

Normalize a path to use '/' separators.

path : string
Returns: string

Type something to start searching.