Header menu logo Nu

PogoShapeCast Type

Describes what shape to cast from the bottom of the character shape to the ground for step detection. Circle diameter scalar and segment width scalar are multiplied with character width (diameter for capsules). Note that a scalar of 1 or higher may collide with vertical walls that the character only touches.

Union cases

Union case Description

CirclePogoShapeCast DiameterScalar

Full Usage: CirclePogoShapeCast DiameterScalar

Parameters:
    DiameterScalar : single

DiameterScalar : single

PointPogoShapeCast

Full Usage: PointPogoShapeCast

SegmentPogoShapeCast WidthScalar

Full Usage: SegmentPogoShapeCast WidthScalar

Parameters:
    WidthScalar : single

WidthScalar : single

Instance members

Instance member Description

this.IsCirclePogoShapeCast

Full Usage: this.IsCirclePogoShapeCast

Returns: bool
Returns: bool

this.IsPointPogoShapeCast

Full Usage: this.IsPointPogoShapeCast

Returns: bool
Returns: bool

this.IsSegmentPogoShapeCast

Full Usage: this.IsSegmentPogoShapeCast

Returns: bool
Returns: bool

Type something to start searching.