Header menu logo Nu

PogoSpringCharacterProperties Type

The properties specific to the modeling a character body with continuous ground contact using a spring-damper system, more commonly used in organic or dynamic environments, with a more natural feeling on uneven surfaces. RestLengthScalar is a multiplier of capsule cylinder height.

Record fields

Record Field Description

AdditionalCollisionMask

Full Usage: AdditionalCollisionMask

Field type: uint64
Field type: uint64

PogoDampingRatio

Full Usage: PogoDampingRatio

Field type: single
Field type: single

PogoFrequency

Full Usage: PogoFrequency

Field type: single
Field type: single

PogoRestLengthScalar

Full Usage: PogoRestLengthScalar

Field type: single
Field type: single

PogoShapeCast

Full Usage: PogoShapeCast

Field type: PogoShapeCast
Field type: PogoShapeCast

Static members

Static member Description

PogoSpringCharacterProperties.defaultProperties

Full Usage: PogoSpringCharacterProperties.defaultProperties

Returns: PogoSpringCharacterProperties

The default character properties.

Returns: PogoSpringCharacterProperties

Type something to start searching.