Header menu logo Nu

PropertyDescriptor Module

PropertyDescriptor functions.

Functions and values

Function or value Description

PropertyDescriptor.containsPropertyDescriptor propertyName simulant world

Full Usage: PropertyDescriptor.containsPropertyDescriptor propertyName simulant world

Parameters:
Returns: bool

Check that an entity contains the given property descriptor.

propertyName : string
simulant : Simulant
world : World
Returns: bool

PropertyDescriptor.getPropertyDescriptors simulant world

Full Usage: PropertyDescriptor.getPropertyDescriptors simulant world

Parameters:
Returns: (Type voption * PropertyDescriptor) seq

Get the property descriptors and optional containing xtension type name (None for intrinsic properties), as constructed from the given function in the given context.

simulant : Simulant
world : World
Returns: (Type voption * PropertyDescriptor) seq

PropertyDescriptor.tryGetValue propertyDescriptor simulant world

Full Usage: PropertyDescriptor.tryGetValue propertyDescriptor simulant world

Parameters:
Returns: obj option

Attempt to get the simulant's property value.

propertyDescriptor : PropertyDescriptor
simulant : Simulant
world : World
Returns: obj option

PropertyDescriptor.trySetValue propertyDescriptor propertyValue simulant world

Full Usage: PropertyDescriptor.trySetValue propertyDescriptor propertyValue simulant world

Parameters:
Returns: bool * bool

Attempt to set the simulant's property value.

propertyDescriptor : PropertyDescriptor
propertyValue : 'a
simulant : Simulant
world : World
Returns: bool * bool

Type something to start searching.