Header menu logo Nu

Protection Type

Describes the protection category of a simulant.

Union cases

Union case Description

DeclarativeProtection

Full Usage: DeclarativeProtection

A simulant that is protected from deletion in editor and does not serialize due to its declarative nature.

ManualProtection

Full Usage: ManualProtection

A simulant that is protected from deletion in editor but still serializes.

Unprotected

Full Usage: Unprotected

A simulant that is unprotected from deletion in editor.

Instance members

Instance member Description

this.IsDeclarativeProtection

Full Usage: this.IsDeclarativeProtection

Returns: bool
Returns: bool

this.IsManualProtection

Full Usage: this.IsManualProtection

Returns: bool
Returns: bool

this.IsUnprotected

Full Usage: this.IsUnprotected

Returns: bool
Returns: bool

Type something to start searching.