Header menu logo Nu

ScreenPropertyDescriptor Module

Screen PropertyDescriptor functions.

Functions and values

Function or value Description

ScreenPropertyDescriptor.containsPropertyDescriptor propertyName screen world

Full Usage: ScreenPropertyDescriptor.containsPropertyDescriptor propertyName screen world

Parameters:
Returns: bool

Check that the described property exists for the given screen.

propertyName : string
screen : Screen
world : World
Returns: bool

ScreenPropertyDescriptor.getCategorizedPropertyDescriptors screen world

Full Usage: ScreenPropertyDescriptor.getCategorizedPropertyDescriptors screen world

Parameters:
Returns: (Either<string, Type> * PropertyDescriptor seq) seq

Get the editor-categorized property descriptors for the given screen.

screen : Screen
world : World
Returns: (Either<string, Type> * PropertyDescriptor seq) seq

ScreenPropertyDescriptor.getEditable propertyDescriptor

Full Usage: ScreenPropertyDescriptor.getEditable propertyDescriptor

Parameters:
Returns: bool

Get whether the described property is editable.

propertyDescriptor : PropertyDescriptor
Returns: bool

ScreenPropertyDescriptor.getPropertyDescriptors screen world

Full Usage: ScreenPropertyDescriptor.getPropertyDescriptors screen world

Parameters:
Returns: PropertyDescriptor seq

Get the property descriptors for the given screen.

screen : Screen
world : World
Returns: PropertyDescriptor seq

ScreenPropertyDescriptor.getValue propertyDescriptor screen world

Full Usage: ScreenPropertyDescriptor.getValue propertyDescriptor screen world

Parameters:
Returns: obj

Get the value of the described property for the given screen.

propertyDescriptor : PropertyDescriptor
screen : Screen
world : World
Returns: obj

ScreenPropertyDescriptor.trySetValue value propertyDescriptor screen world

Full Usage: ScreenPropertyDescriptor.trySetValue value propertyDescriptor screen world

Parameters:
Returns: Either<string, unit>

Attempt to set the value of the described property for the given screen.

value : obj
propertyDescriptor : PropertyDescriptor
screen : Screen
world : World
Returns: Either<string, unit>

Type something to start searching.