Header menu logo Nu

SimulantPropertyDescriptor Module

Simulant PropertyDescriptor functions.

Functions and values

Function or value Description

SimulantPropertyDescriptor.containsPropertyDescriptor propertyName simulant world

Full Usage: SimulantPropertyDescriptor.containsPropertyDescriptor propertyName simulant world

Parameters:
Returns: bool

Check that the described property exists for the given simulant.

propertyName : string
simulant : Simulant
world : World
Returns: bool

SimulantPropertyDescriptor.getCategorizedPropertyDescriptors simulant world

Full Usage: SimulantPropertyDescriptor.getCategorizedPropertyDescriptors simulant world

Parameters:
Returns: (Either<string, Type> * PropertyDescriptor seq) seq

Get the editor-categorized property descriptors for the given simulant.

simulant : Simulant
world : World
Returns: (Either<string, Type> * PropertyDescriptor seq) seq

SimulantPropertyDescriptor.getEditable propertyDesciptor simulant

Full Usage: SimulantPropertyDescriptor.getEditable propertyDesciptor simulant

Parameters:
Returns: bool

Get whether the described property is editable.

propertyDesciptor : PropertyDescriptor
simulant : Simulant
Returns: bool

SimulantPropertyDescriptor.getPropertyDescriptors simulant world

Full Usage: SimulantPropertyDescriptor.getPropertyDescriptors simulant world

Parameters:
Returns: PropertyDescriptor seq

Get the property descriptors for the given simulant.

simulant : Simulant
world : World
Returns: PropertyDescriptor seq

SimulantPropertyDescriptor.getValue propertyDescriptor simulant world

Full Usage: SimulantPropertyDescriptor.getValue propertyDescriptor simulant world

Parameters:
Returns: obj

Get the value of the described property for the given simulant.

propertyDescriptor : PropertyDescriptor
simulant : Simulant
world : World
Returns: obj

SimulantPropertyDescriptor.trySetValue value propertyDescriptor simulant world

Full Usage: SimulantPropertyDescriptor.trySetValue value propertyDescriptor simulant world

Parameters:
Returns: Either<string, unit>

Attempt to set the value of the described property for the given simulant.

value : 'a
propertyDescriptor : PropertyDescriptor
simulant : Simulant
world : World
Returns: Either<string, unit>

Type something to start searching.