Header menu logo Nu

SpiralContour2dFacet Type

Augments an entity with the behavior of a 2d polygon spiral contour. Augments an entity with the behavior of a 2d polygon spiral contour.

Constructors

Constructor Description

SpiralContour2dFacet()

Full Usage: SpiralContour2dFacet()

Returns: SpiralContour2dFacet
Returns: SpiralContour2dFacet

Static members

Static member Description

SpiralContour2dFacet.Properties

Full Usage: SpiralContour2dFacet.Properties

Returns: PropertyDefinition list
Returns: PropertyDefinition list

Type something to start searching.