StairSteppingCharacterProperties Type
The properties specific to the modeling a character body with discrete stair-stepping and slope physics, more commonly used in man-made, structured or grid-like environments with explicit stairs and slopes.
Record fields
| Record Field | Description |
Full Usage:
CollisionPadding
Field type: single
|
|
Full Usage:
CollisionTolerance
Field type: single
|
|
Full Usage:
SlopeMax
Field type: single
|
|
Full Usage:
StairCosAngleForwardContact
Field type: single
|
|
|
|
|
|
Full Usage:
StairStepForwardMin
Field type: single
|
|
Full Usage:
StairStepForwardTest
Field type: single
|
|
|
|
Static members
| Static member | Description |
Full Usage:
StairSteppingCharacterProperties.defaultProperties
Returns: StairSteppingCharacterProperties
|
|
Nu