Header menu logo Nu

TextInputData Type

The data for a text input event for one character that may be represented as multiple Unicode code points for non-English languages.

Record fields

Record Field Description

TextInput

Full Usage: TextInput

Field type: string
Field type: string

Type something to start searching.