Header menu logo Nu

Nu.Vulkan Namespace

Type/Module Description

Attachment

Attachment operations.

AttachmentMode

Determines whether a texture is intended as an attachment, what sort, and whether to parallelize for frames in flight.

BackgroundingResponseState

Represents a strict cycle ensuring that any presentation resources (surface and swapchains) that exist or are being created during the onset of app backgrounding on a mobile device are torn down/cancelled.

BloomApplyStruct

BloomDownSampleStruct

BloomExtractStruct

BloomUpSampleStruct

BufferType

The type of vulkan buffer being utilized.

BufferWrapper

Wraps a vulkan buffer and its metadata. OPTIMIZATION: this is a struct to avoid reduce GC presence.

ChromaticAberrationStruct

ConcurrentCommandQueue

A command queue that internally synchronizes use across multiple threads.

Contour

Slug GPU contour pipeline (analytic coverage via horizontal + vertical ray casting).

ContourQuad

A unit quad used for contour rendering. Vertices are in [0,1] range so the vertex shader can map them directly to the bounding box via bboxMin + position * bboxSize.

CubeMap

Cube map operations.

CubeMapClient

Memoizes cube map loads (and may at some point potentially thread them).

CubeMapGeometry

Describes some cube map geometry that's loaded into VRAM.

CubeMapKey

The key identifying a cube map.

CubeMapPipeline

Describes a cube map pipeline that's loaded into GPU.

CubeMapSurface

Describes a renderable cube map surface.

DepthOfFieldStruct

DescriptorBinding

Describes a binding for a resource descriptor (aka uniform).

DescriptorSet

Represents a generalized descriptor set for the purposes of Nu's vulkan renderer.

DescriptorSet<'k>

Represents a well-typed descriptor set for the purposes of Nu's vulkan renderer.

DescriptorSetDefinition

Represent a description a descriptor set.

DescriptorSetDefinition<'k>

Describes a descriptor set.

DescriptorType

The type of a resource descriptor.

EnvironmentFilterPipeline

Describes an environment filter pipeline that's loaded into GPU.

EnvironmentFilterStruct

Represents the environment filter data for a shader.

EyeStruct

Represents the eye data for a shader.

FilterBloomApplyPipeline

Describes a bloom apply filter pipeline that's loaded into GPU.

FilterBloomDownSamplePipeline

Describes a bloom down-sample filter pipeline that's loaded into GPU.

FilterBloomExtractPipeline

Describes a bloom extract filter pipeline that's loaded into GPU.

FilterBloomUpSamplePipeline

Describes a bloom up-sample filter pipeline that's loaded into GPU.

FilterBoxPipeline

Describes a box filter pipeline that's loaded into GPU.

FilterChromaticAberrationPipeline

Describes a chromatic aberration filter pipeline that's loaded into GPU.

FilterDepthOfFieldPipeline

Describes a depth-of-field filter pipeline that's loaded into GPU.

FilterDownSamplePipeline

Describes a down-sample filter pipeline that's loaded into GPU.

FilterFxaaPipeline

Describes an fxaa filter pipeline that's loaded into GPU.

FilterGammaCorrectionPipeline

Describes a gamma-correction filter pipeline that's loaded into GPU.

FilterGaussianDofPipeline

Describes a depth-of-field gaussian filter pipeline that's loaded into GPU.

FilterGaussianEsmPipeline

Describes an esm gaussian filter pipeline that's loaded into GPU.

FilterToneMappingPipeline

Describes a tone-mapping filter pipeline that's loaded into GPU.

FilterUpSamplePipeline

Describes an up-sample filter pipeline that's loaded into GPU.

FxaaStruct

GaussianDofStruct

GaussianEsmStruct

Hl

High-level vulkan operations.

ImageFormat

The format of an image.

ImageLayout

An image layout in its access and pipeline stage context.

LazyTexture

A texture that can be loaded from another thread.

Lighting2Struct

LightingStruct

LightMap (Module)

Light map operations.

LightMap (Type)

A collection of maps consisting a light map.

LightMapStruct

LightsGeneralStruct

LightStruct

LoadOperation

The load operation for render pass attachments.

MipmapMode

Determines whether a texture has mipmaps, and whether they are handled manually or automatically.

PhysicalDevice

A representation of a physical device and associated information.

PhysicallyBased

Physically-based rendering operations.

PhysicallyBasedAttachments

A set of physically-based attachments that support a given viewport.

PhysicallyBasedDeferredAmbientPipeline

Describes the ambient pass of a deferred physically-based pipeline that's loaded into GPU.

PhysicallyBasedDeferredColoringPipeline

Describes the coloring pass of a deferred physically-based pipeline that's loaded into GPU.

PhysicallyBasedDeferredCompositionPipeline

Describes the composition pass of a deferred physically-based pipeline that's loaded into GPU.

PhysicallyBasedDeferredEnvironmentFilterPipeline

Describes the environment filter pass of a deferred physically-based pipeline that's loaded into GPU.

PhysicallyBasedDeferredFoggingPipeline

Describes the fogging pass of a deferred physically-based pipeline that's loaded into GPU.

PhysicallyBasedDeferredIrradiancePipeline

Describes the irradiance pass of a deferred physically-based pipeline that's loaded into GPU.

PhysicallyBasedDeferredLightingPipeline

Describes the lighting pass of a deferred physically-based pipeline that's loaded into GPU.

PhysicallyBasedDeferredLightMappingPipeline

Describes the light mapping pass of a deferred physically-based pipeline that's loaded into GPU.

PhysicallyBasedDeferredSsaoPipeline

Describes the ssao pass of a deferred physically-based pipeline that's loaded into GPU.

PhysicallyBasedDeferredTerrainPipeline

Describes a physically-based deferred terrain pipeline that's loaded into GPU.

PhysicallyBasedGeometry

Describes some physically-based geometry that's loaded into VRAM.

PhysicallyBasedLight

A light inside a physically-based static model.

PhysicallyBasedLightProbe

A light probe inside a physically-based static model.

PhysicallyBasedMaterial

Describes a physically-based material.

PhysicallyBasedMaterialProperties

Describes the configurable properties of a physically-based material.

PhysicallyBasedModel

A physically-based model.

PhysicallyBasedPart

A part of a physically-based hierarchy.

PhysicallyBasedPipeline

Describes a physically-based pipeline that's loaded into GPU.

PhysicallyBasedPipelines

Physically-based pipelines.

PhysicallyBasedSceneClient

Memoizes physically-based scene loads.

PhysicallyBasedShadowPipeline

Describes a physically-based depth pipeline that's loaded into GPU.

PhysicallyBasedSurface

Describes a renderable physically-based surface.

PhysicallyBasedSurfaceFns

Physically-based surface operations.

Pipeline

An abstraction of a rendering pipeline.

PixelFormat

The pixel format of an image.

PushConstant

Describes a push constant.

Sampler

A Vulkan sampler.

ShaderStage

A shader stage or combination.

ShadowFragStruct

ShadowVertStruct

ShapeGPU

 Per-shape data uploaded to the GPU uniform buffer.
 Layout matches the GLSL std430 layout in Contour.vert/frag:
   mat4 MVP (64B), vec4 color (16B), uint curveCount (4B), uint flags (4B),
   uint hBands (4B), uint vBands (4B), vec2 bboxMin (8B), vec2 bboxSize (8B),
   vec4 bandTransform (16B) = 128B.
 The vertex shader maps a [0,1] unit quad to [bboxMin, bboxMin+bboxSize].

 Flags bit layout (must match Contour.frag):
   bit 0: fillMode (0=NonZero, 1=EvenOdd)

SkyBox

Sky box operations.

SkyBoxPipeline

Describes a sky box pipeline that's loaded into GPU.

SkyBoxStruct

SpriteBatch

Sprite batch operations.

SpriteBatchEnv

The environment that contains the internal state required for batching sprites. TODO: P1: consider altering the representation of batched vertex data so that all the vertex data can be uploaded with a single driver call.

SpriteBatchState

The state of a sprite batch.

SpriteFragStruct

SpriteSingleton

Single sprite operations.

SpriteStruct

SpriteVertStruct

SsaoStruct

Surface

The state of the program's OS-provided rendering surface.

Swapchain

A swapchain and its assets that may be refreshed for a different screen size.

SwapchainWrapper

A wrapper for a vulkan swapchain and its assets.

TerrainFragStruct

Texture

A 2d texture.

TextureClient

Memoizes and optionally threads texture loads.

TextureCompression

The compression to use for a texture, if any.

TextureData

Describes data loaded from a texture.

TextureDumpster

A container for textures to be destroyed once their frame has executed.

TextureInternal

An internal representation of a texture as managed by Vulkan.

TextureLoadThread

The thread on which a texture is loaded.

TextureMetadata

A Vulkan texture's metadata.

TextureServer

Populate the vulkan textures and handles of lazy textures in a threaded manner. TODO: abstract this to interface that can represent either inline or threaded implementation.

TextureType

Determines how a texture is configured based on intended usage.

TextureWrapper

Wraps a vulkan texture in the various ways that vulkan provides.

ToneMappingStruct

VertexAttribFormat

The format of a vertex attribute.

VertexAttribute

Describes a vertex attribute in the context of a vertex binding.

VertexBinding

Describes a binding for a vertex and its attributes.

ViewProjectionStruct

Vulkan

Vulkan operations.

VulkanBlend

A blend setting for a Vulkan pipeline. NOTE: this type's name is prefixed with "Vulkan" in order to reliably disambiguate it from Nu.Blend.

VulkanBuffer

Represents a dynamically growing multibuffer with parallel underlying vulkan buffers. Maintains an internal cursor that selects the currently active buffer, which is reset via beginFrame and advanced to the next vulkan buffer with advance. Automatically resizes when usage exceeds its capacity and creates additional buffers when the cursor moves beyond current capacity. This type is intended for transient or frequently updated GPU data such as storage data, uniform data, and streaming data. NOTE: this type's name is prefixed with "Vulkan" in order to reliably disambiguate it from System.Buffer.

VulkanContext

Exposes the vulkan handles that must be globally accessible within the renderer. TODO: P1: group fields / properties by role rather than type.

Type something to start searching.