Header menu logo Nu

AttachmentMode Type

Determines whether a texture is intended as an attachment, what sort, and whether to parallelize for frames in flight.

Union cases

Union case Description

AttachmentColor IsParallel

Full Usage: AttachmentColor IsParallel

Parameters:
    IsParallel : bool

IsParallel : bool

AttachmentDepth IsParallel

Full Usage: AttachmentDepth IsParallel

Parameters:
    IsParallel : bool

IsParallel : bool

AttachmentNone

Full Usage: AttachmentNone

Instance members

Instance member Description

this.IsAttachmentColor

Full Usage: this.IsAttachmentColor

Returns: bool
Returns: bool

this.IsAttachmentDepth

Full Usage: this.IsAttachmentDepth

Returns: bool
Returns: bool

this.IsAttachmentNone

Full Usage: this.IsAttachmentNone

Returns: bool
Returns: bool

this.VkImageAspectFlags

Full Usage: this.VkImageAspectFlags

Returns: VkImageAspectFlags

The VkImageAspectFlags for a given attachment mode. This is because, unlike layout transitions, image view creation only needs the *intended* image aspect e.g. depth, not every aspect contained in the format e.g. depth & stencil.

Returns: VkImageAspectFlags

Type something to start searching.