Header menu logo Nu

BackgroundingResponseState Type

Represents a strict cycle ensuring that any presentation resources (surface and swapchains) that exist or are being created during the onset of app backgrounding on a mobile device are torn down/cancelled.

Union cases

Union case Description

PresentationSetupInitiated

Full Usage: PresentationSetupInitiated

Setup of presentation resources has begun and may be complete.

PresentationTeardownComplete

Full Usage: PresentationTeardownComplete

Presentation resources have been destroyed and restoration will commence when app is back in foreground.

PresentationTeardownPending

Full Usage: PresentationTeardownPending

Presentation resources can no longer be trusted as app has commenced backgrounding.

Instance members

Instance member Description

this.IsPresentationSetupInitiated

Full Usage: this.IsPresentationSetupInitiated

Returns: bool
Returns: bool

this.IsPresentationTeardownComplete

Full Usage: this.IsPresentationTeardownComplete

Returns: bool
Returns: bool

this.IsPresentationTeardownPending

Full Usage: this.IsPresentationTeardownPending

Returns: bool
Returns: bool

Type something to start searching.