Header menu logo Nu

ConcurrentCommandQueue Type

A command queue that internally synchronizes use across multiple threads.

Record fields

Record Field Description

Lock_

Full Usage: Lock_

Field type: obj
Field type: obj

VkQueue_

Full Usage: VkQueue_

Field type: VkQueue
Field type: VkQueue

Static members

Static member Description

ConcurrentCommandQueue.create queueFamilyIndex queueIndex

Full Usage: ConcurrentCommandQueue.create queueFamilyIndex queueIndex

Parameters:
    queueFamilyIndex : uint32
    queueIndex : uint32

Returns: ConcurrentCommandQueue

Create a ConcurrentCommandQueue.

queueFamilyIndex : uint32
queueIndex : uint32
Returns: ConcurrentCommandQueue

ConcurrentCommandQueue.runTransient commandBuffer commandPool finishFence commandQueue

Full Usage: ConcurrentCommandQueue.runTransient commandBuffer commandPool finishFence commandQueue

Parameters:

Transiently run and then free the given command buffer. Command pool and finish fence must NOT be shared between threads!

commandBuffer : VkCommandBuffer
commandPool : VkCommandPool
finishFence : VkFence
commandQueue : ConcurrentCommandQueue

ConcurrentCommandQueue.waitIdle queue

Full Usage: ConcurrentCommandQueue.waitIdle queue

Parameters:

Wait for Queue to finish execution.

queue : ConcurrentCommandQueue

ConcurrentCommandQueue.withLock queue op

Full Usage: ConcurrentCommandQueue.withLock queue op

Parameters:
Returns: 'a

Perform an arbitrary operation on the internal vulkan queue.

queue : ConcurrentCommandQueue
op : VkQueue -> 'a
Returns: 'a

Type something to start searching.