PhysicallyBasedDeferredLightMappingPipeline Type
Describes the light mapping pass of a deferred physically-based pipeline that's loaded into GPU.
Record fields
| Record Field | Description |
|
|
|
|
|
|
|
Describes the light mapping pass of a deferred physically-based pipeline that's loaded into GPU.
| Record Field | Description |
|
|
|
|
|
|
|