Header menu logo Nu

SpriteBatchEnv Type

The environment that contains the internal state required for batching sprites. TODO: P1: consider altering the representation of batched vertex data so that all the vertex data can be uploaded with a single driver call.

Record fields

Record Field Description

Colors

Full Usage: Colors

Field type: Vector4 array
Field type: Vector4 array

FilteredSampler

Full Usage: FilteredSampler

Field type: Sampler
Field type: Sampler

Perimeters

Full Usage: Perimeters

Field type: Vector4 array
Field type: Vector4 array

Pipeline

Full Usage: Pipeline

Field type: Pipeline
Field type: Pipeline

Pivots

Full Usage: Pivots

Field type: Vector2 array
Field type: Vector2 array

Rotations

Full Usage: Rotations

Field type: single array
Field type: single array

SpriteIndex

Full Usage: SpriteIndex

Field type: int
Modifiers: mutable
Field type: int

SpritesUniform

Full Usage: SpritesUniform

Field type: VulkanBuffer
Field type: VulkanBuffer

State

Full Usage: State

Field type: SpriteBatchState
Modifiers: mutable
Field type: SpriteBatchState

TexCoordses

Full Usage: TexCoordses

Field type: Vector4 array
Field type: Vector4 array

UnfilteredSampler

Full Usage: UnfilteredSampler

Field type: Sampler
Field type: Sampler

ViewProjection2dAbsolute

Full Usage: ViewProjection2dAbsolute

Field type: Matrix4x4
Modifiers: mutable
Field type: Matrix4x4

ViewProjection2dRelative

Full Usage: ViewProjection2dRelative

Field type: Matrix4x4
Modifiers: mutable
Field type: Matrix4x4

ViewProjectionClipAbsolute

Full Usage: ViewProjectionClipAbsolute

Field type: Matrix4x4
Modifiers: mutable
Field type: Matrix4x4

ViewProjectionClipRelative

Full Usage: ViewProjectionClipRelative

Field type: Matrix4x4
Modifiers: mutable
Field type: Matrix4x4

ViewProjectionUniform

Full Usage: ViewProjectionUniform

Field type: VulkanBuffer
Field type: VulkanBuffer

VulkanContext

Full Usage: VulkanContext

Field type: VulkanContext
Field type: VulkanContext

Type something to start searching.