Header menu logo Nu

Swapchain Type

A swapchain and its assets that may be refreshed for a different screen size.

Record fields

Record Field Description

SurfaceFormat_

Full Usage: SurfaceFormat_

Field type: VkSurfaceFormatKHR
Field type: VkSurfaceFormatKHR

SwapchainWrapperOpt_

Full Usage: SwapchainWrapperOpt_

Field type: SwapchainWrapper option
Modifiers: mutable
Field type: SwapchainWrapper option

Window_

Full Usage: Window_

Field type: nativeptr<SDL_Window>
Field type: nativeptr<SDL_Window>

Instance members

Instance member Description

this.SwapchainWrapperOpt

Full Usage: this.SwapchainWrapperOpt

Returns: SwapchainWrapper option

The underlying vulkan swapchain when available.

Returns: SwapchainWrapper option

Static members

Static member Description

Swapchain.create surfaceFormat physicalDevice window

Full Usage: Swapchain.create surfaceFormat physicalDevice window

Parameters:
Returns: Swapchain

Create a Swapchain.

surfaceFormat : VkSurfaceFormatKHR
physicalDevice : PhysicalDevice
window : nativeptr<SDL_Window>
Returns: Swapchain

Swapchain.destroy swapchain

Full Usage: Swapchain.destroy swapchain

Parameters:

Destroy a Swapchain.

swapchain : Swapchain

Swapchain.tryRecreateSurfaceAndEnsureSwapchainWrapper tryCreateVkSurface physicalDevice swapchain instance

Full Usage: Swapchain.tryRecreateSurfaceAndEnsureSwapchainWrapper tryCreateVkSurface physicalDevice swapchain instance

Parameters:

Attempt to recreate the current vulkan surface and ensure swapchain validity.

tryCreateVkSurface : nativeptr<SDL_Window> -> 'a -> VkSurfaceKHR option
physicalDevice : PhysicalDevice
swapchain : Swapchain
instance : 'a

Type something to start searching.