Header menu logo Nu

TextureServer Type

Populate the vulkan textures and handles of lazy textures in a threaded manner. TODO: abstract this to interface that can represent either inline or threaded implementation.

Constructors

Constructor Description

TextureServer(lazyTextureQueues, context)

Full Usage: TextureServer(lazyTextureQueues, context)

Parameters:
Returns: TextureServer
lazyTextureQueues : ConcurrentDictionary<ConcurrentQueue<LazyTexture>, ConcurrentQueue<LazyTexture>>
context : VulkanContext
Returns: TextureServer

Instance members

Instance member Description

this.Start

Full Usage: this.Start

this.Terminate

Full Usage: this.Terminate

Type something to start searching.