WorldImSim Module
ImSim API for the world.
Functions and values
| Function or value | Description |
|
|
|
|
|
Type extensions
| Type extension | Description |
Full Usage:
this.ImSimInitializing
Parameters:
unit
Returns: bool
|
|
Full Usage:
this.ImSimInitializing
Returns: bool
|
|
Full Usage:
this.ImSimReinitializing
Parameters:
unit
Returns: bool
|
|
Full Usage:
this.ImSimReinitializing
Returns: bool
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
|
|
|
|
|
|
ImSim declare a basic static billboard emitter with the given arguments. See BasicStaticBillboardEmitterDispatcher.
Extended Type:
|
|
ImSim declare a basic static sprite emitter with the given arguments. See BasicStaticSpriteEmitterDispatcher.
Extended Type:
|
|
|
|
|
|
Extended Type:
|
Full Usage:
World.doBodyJoint2d name args world
Parameters: Returns: BodyJointId * FQueue<BodyEventData>
|
|
Full Usage:
World.doBodyJoint3d name args world
Parameters: Returns: BodyJointId * FQueue<BodyEventData>
|
|
|
|
|
|
|
|
|
|
|
|
|
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
|
|
|
|
|
|
Extended Type:
|
|
Extended Type:
|
|
|
|
|
|
|
|
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
|
|
|
|
Extended Type:
|
|
|
|
Extended Type:
|
|
|
|
Extended Type:
|
|
|
|
|
|
|
|
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
ImSim declare a static model hierarchy with the given arguments. See StaticModelHierarchyDispatcher.
Extended Type:
|
|
Extended Type:
|
|
Extended Type:
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
World.doSubscriptionToBodyEvents name entity world
Parameters: Returns: FQueue<BodyEventData>
|
|
Full Usage:
World.doSubscriptionToSelectionEvents name screen world
Parameters: Returns: FQueue<SelectionEventData>
|
|
|
|
|
Extended Type:
|
|
|
|
|
|
|
|
|
|
ImSim declare a 2d wedge (pie slice) contour with the given arguments. See WedgeContour2dDispatcher.
Extended Type:
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
World.initBodyResult mapResult entity world
Parameters:
('a -> FQueue<BodyEventData>) -> World -> unit
entity : Entity
world : World
|
|
|
|
|
|
|
|
|
|
|
Nu