WorldState Type
The world state, in a functional programming sense. Hosts the simulation state, the dependencies needed to implement a game, messages to be consumed by the various engine subsystems, and general configuration data. This type is immutable enough to allows efficient snapshots and later restoration, such as for undo and redo, with very little additional code.
Record fields
| Record Field | Description |
|
|
|
|
Full Usage:
EntityCachedOpt
Field type: KeyedCache<KeyValuePair<Entity, SUMap<Entity, EntityState>>, EntityState>
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Nu