'a Address Type
Specifies the address of an identifiable value. OPTIMIZATION: Names is an array only for speed; it is invalid to mutate it. TODO: change Names to the proposed F# block type when available? TODO: have Address constructors throw in Debug mode on invalid address names or if ellipses (...) are used in the wrong place (not at the end).
Record fields
| Record Field | Description |
Full Usage:
Anonymous
Field type: bool
|
|
Full Usage:
HashCode
Field type: int
|
|
Full Usage:
Names
Field type: string array
|
|
Instance members
| Instance member | Description |
Full Usage:
this.Length
Returns: int
|
|
Full Usage:
this.Relative
Returns: bool
|
Static members
| Static member | Description |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Address.assertAddressName name
Parameters:
string
|
|
Full Usage:
Address.assertIdentifierName name
Parameters:
string
|
Assert that an identifier name contains none of the invalid forms, specifically - [] is reserved as the empty address string / is reserved as the name separator * is reserved as the name wildcard ... is reserved as the address tail wildcard ^ is reserved as the parent symbol ~ is reserved as the current symbol
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Address.findIndex finder address
Parameters:
string -> bool
address : 'a Address
Returns: int
|
|
|
|
|
|
Full Usage:
Address.getName address
Parameters:
'a Address
Returns: string
Modifiers: inline |
|
Full Usage:
Address.getNames address
Parameters:
'a Address
Returns: string array
Modifiers: inline |
|
|
|
|
|
Full Usage:
Address.indexOf name address
Parameters:
string
address : 'a Address
Returns: int
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Address.validateAddressName name
Parameters:
string
Returns: bool
|
|
Full Usage:
Address.validateIdentifierName name
Parameters:
string
Returns: bool
|
Check that an identifier name contains none of the invalid forms, specifically - [] is reserved as the empty address string / is reserved as the name separator * is reserved as the name wildcard ... is reserved as the address tail wildcard ^ is reserved as the parent symbol ~ is reserved as the current symbol
|
|
|
Nu