Contour Module
Contour operations. TODO: P0: get rid of excess frame-based allocation here, such as potentially by using memoization. TODO: see if it won't be too disruptive to make this code conform to our code standard.
Functions and values
| Function or value | Description |
Full Usage:
Contour.make fill stroke commands scale
Parameters:
ContourFill
stroke : ContourStroke
commands : ContourCommand seq
scale : Vector2
Returns: Contour
|
|
Full Usage:
Contour.packCurvesGPU curves
Parameters:
ContourCurve array
Returns: Vector4 array
|
Nu