PogoShapeCast Type
Describes what shape to cast from the bottom of the character shape to the ground for step detection. Circle diameter scalar and segment width scalar are multiplied with character width (diameter for capsules). Note that a scalar of 1 or higher may collide with vertical walls that the character only touches.
Union cases
| Union case | Description |
Full Usage:
CirclePogoShapeCast DiameterScalar
Parameters:
single
|
|
Full Usage:
PointPogoShapeCast
|
|
Full Usage:
SegmentPogoShapeCast WidthScalar
Parameters:
single
|
|
Instance members
| Instance member | Description |
Full Usage:
this.IsCirclePogoShapeCast
Returns: bool
|
|
Full Usage:
this.IsPointPogoShapeCast
Returns: bool
|
|
Full Usage:
this.IsSegmentPogoShapeCast
Returns: bool
|
|
Nu