PogoSpringCharacterProperties Type
The properties specific to the modeling a character body with continuous ground contact using a spring-damper system, more commonly used in organic or dynamic environments, with a more natural feeling on uneven surfaces. RestLengthScalar is a multiplier of capsule cylinder height.
Record fields
| Record Field | Description |
Full Usage:
AdditionalCollisionMask
Field type: uint64
|
|
Full Usage:
PogoDampingRatio
Field type: single
|
|
Full Usage:
PogoFrequency
Field type: single
|
|
Full Usage:
PogoRestLengthScalar
Field type: single
|
|
|
|
Static members
| Static member | Description |
|
|
Nu