SpiralContour2dFacet Type
Augments an entity with the behavior of a 2d polygon spiral contour. Augments an entity with the behavior of a 2d polygon spiral contour.
Constructors
| Constructor | Description |
|
|
Static members
| Static member | Description |
|
|
Nu