TextInputData Type
The data for a text input event for one character that may be represented as multiple Unicode code points for non-English languages.
Record fields
| Record Field | Description |
Full Usage:
TextInput
Field type: string
|
|
Nu