AttachmentMode Type
Determines whether a texture is intended as an attachment, what sort, and whether to parallelize for frames in flight.
Union cases
| Union case | Description |
Full Usage:
AttachmentColor IsParallel
Parameters:
bool
|
|
Full Usage:
AttachmentDepth IsParallel
Parameters:
bool
|
|
Full Usage:
AttachmentNone
|
Instance members
| Instance member | Description |
Full Usage:
this.IsAttachmentColor
Returns: bool
|
|
Full Usage:
this.IsAttachmentDepth
Returns: bool
|
|
Full Usage:
this.IsAttachmentNone
Returns: bool
|
|
|
|
Nu