BackgroundingResponseState Type
Represents a strict cycle ensuring that any presentation resources (surface and swapchains) that exist or are being created during the onset of app backgrounding on a mobile device are torn down/cancelled.
Union cases
| Union case | Description |
Full Usage:
PresentationSetupInitiated
|
|
Full Usage:
PresentationTeardownComplete
|
|
Full Usage:
PresentationTeardownPending
|
Instance members
| Instance member | Description |
Full Usage:
this.IsPresentationSetupInitiated
Returns: bool
|
|
Full Usage:
this.IsPresentationTeardownComplete
Returns: bool
|
|
Full Usage:
this.IsPresentationTeardownPending
Returns: bool
|
|
Nu