SpriteBatchEnv Type
The environment that contains the internal state required for batching sprites. TODO: P1: consider altering the representation of batched vertex data so that all the vertex data can be uploaded with a single driver call.
Record fields
| Record Field | Description |
|
|
|
|
|
|
|
|
|
|
Full Usage:
Rotations
Field type: single array
|
|
Full Usage:
SpriteIndex
Field type: int
Modifiers: mutable |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Nu