TextureServer Type
Populate the vulkan textures and handles of lazy textures in a threaded manner. TODO: abstract this to interface that can represent either inline or threaded implementation.
Constructors
| Constructor | Description |
Full Usage:
TextureServer(lazyTextureQueues, context)
Parameters:
ConcurrentDictionary<ConcurrentQueue<LazyTexture>, ConcurrentQueue<LazyTexture>>
context : VulkanContext
Returns: TextureServer
|
|
Instance members
| Instance member | Description |
Full Usage:
this.Start
|
|
Full Usage:
this.Terminate
|
Nu